=====
Kazoo
=====

.. image:: https://secure.travis-ci.org/python-zk/kazoo.png?branch=master
   :width: 82px
   :height: 13px
   :alt: Travis CI build report
   :target: https://secure.travis-ci.org/#!/python-zk/kazoo

``kazoo`` implements a higher level API to `Apache Zookeeper`_ for Python
clients.

See `the full docs`_ for more  information.

License
=======

``kazoo`` is offered under the Apache License 2.0.

Authors
=======

``kazoo`` started under the `Nimbus Project`_ and through collaboration with
the open-source community has been merged with code from `Mozilla`_ and the
`Zope Corporation`_.

.. _Apache Zookeeper: http://zookeeper.apache.org/
.. _the full docs: http://kazoo.rtfd.org/
.. _Nimbus Project: http://www.nimbusproject.org/
.. _Zope Corporation: http://zope.com/
.. _Mozilla: http://www.mozilla.org/
